@@ -1,6 +1,5 @@
 var namespacegko =
 [
-    [ "accessor", "namespacegko_1_1accessor.html", "namespacegko_1_1accessor" ],
     [ "batch", null, [
       [ "log", "namespacegko_1_1batch_1_1log.html", "namespacegko_1_1batch_1_1log" ],
       [ "BatchLinOp", "classgko_1_1batch_1_1BatchLinOp.html", "classgko_1_1batch_1_1BatchLinOp" ],
@@ -9,141 +8,141 @@ var namespacegko =
       [ "MultiVector", "classgko_1_1batch_1_1MultiVector.html", "classgko_1_1batch_1_1MultiVector" ],
       [ "EnableDefaultBatchLinOpFactory", "group__BatchLinOp.html#gaa62d516d392c16b9580dd0d8067a0041", null ]
     ] ],
+    [ "matrix", "namespacegko_1_1matrix.html", "namespacegko_1_1matrix" ],
     [ "experimental", null, [
-      [ "distributed", "namespacegko_1_1experimental_1_1distributed.html", "namespacegko_1_1experimental_1_1distributed" ],
       [ "mpi", "namespacegko_1_1experimental_1_1mpi.html", "namespacegko_1_1experimental_1_1mpi" ],
+      [ "distributed", "namespacegko_1_1experimental_1_1distributed.html", "namespacegko_1_1experimental_1_1distributed" ],
       [ "reorder", "namespacegko_1_1experimental_1_1reorder.html", "namespacegko_1_1experimental_1_1reorder" ]
     ] ],
-    [ "factorization", "namespacegko_1_1factorization.html", "namespacegko_1_1factorization" ],
-    [ "log", "namespacegko_1_1log.html", "namespacegko_1_1log" ],
-    [ "matrix", "namespacegko_1_1matrix.html", "namespacegko_1_1matrix" ],
-    [ "multigrid", "namespacegko_1_1multigrid.html", "namespacegko_1_1multigrid" ],
     [ "name_demangling", "namespacegko_1_1name__demangling.html", [
       [ "get_dynamic_type", "namespacegko_1_1name__demangling.html#a7469320f9401df05fcad48027569cef0", null ],
       [ "get_static_type", "namespacegko_1_1name__demangling.html#a305c6bc422a3babdd1179db5b2859ae3", null ]
     ] ],
+    [ "accessor", "namespacegko_1_1accessor.html", "namespacegko_1_1accessor" ],
+    [ "xstd", "namespacegko_1_1xstd.html", "namespacegko_1_1xstd" ],
+    [ "multigrid", "namespacegko_1_1multigrid.html", "namespacegko_1_1multigrid" ],
+    [ "factorization", "namespacegko_1_1factorization.html", "namespacegko_1_1factorization" ],
+    [ "log", "namespacegko_1_1log.html", "namespacegko_1_1log" ],
+    [ "stop", "namespacegko_1_1stop.html", "namespacegko_1_1stop" ],
     [ "preconditioner", "namespacegko_1_1preconditioner.html", "namespacegko_1_1preconditioner" ],
     [ "reorder", "namespacegko_1_1reorder.html", "namespacegko_1_1reorder" ],
     [ "solver", "namespacegko_1_1solver.html", "namespacegko_1_1solver" ],
-    [ "stop", "namespacegko_1_1stop.html", "namespacegko_1_1stop" ],
     [ "syn", "namespacegko_1_1syn.html", "namespacegko_1_1syn" ],
-    [ "xstd", "namespacegko_1_1xstd.html", "namespacegko_1_1xstd" ],
-    [ "AbsoluteComputable", "classgko_1_1AbsoluteComputable.html", "classgko_1_1AbsoluteComputable" ],
     [ "AbstractFactory", "classgko_1_1AbstractFactory.html", "classgko_1_1AbstractFactory" ],
-    [ "AllocationError", "classgko_1_1AllocationError.html", "classgko_1_1AllocationError" ],
-    [ "Allocator", "classgko_1_1Allocator.html", null ],
-    [ "amd_device", "classgko_1_1amd__device.html", null ],
-    [ "are_all_integral", "structgko_1_1are__all__integral.html", null ],
-    [ "are_all_integral< First, Args... >", "structgko_1_1are__all__integral_3_01First_00_01Args_8_8_8_01_4.html", null ],
+    [ "EnableDefaultFactory", "classgko_1_1EnableDefaultFactory.html", "classgko_1_1EnableDefaultFactory" ],
+    [ "enable_parameters_type", "classgko_1_1enable__parameters__type.html", "classgko_1_1enable__parameters__type" ],
+    [ "deferred_factory_parameter", "classgko_1_1deferred__factory__parameter.html", "classgko_1_1deferred__factory__parameter" ],
     [ "array", "classgko_1_1array.html", "classgko_1_1array" ],
-    [ "BadDimension", "classgko_1_1BadDimension.html", "classgko_1_1BadDimension" ],
     [ "batch_dim", "structgko_1_1batch__dim.html", "structgko_1_1batch__dim" ],
     [ "bfloat16", "classgko_1_1bfloat16.html", null ],
     [ "BlockOperator", "classgko_1_1BlockOperator.html", "classgko_1_1BlockOperator" ],
-    [ "BlockSizeError", "classgko_1_1BlockSizeError.html", "classgko_1_1BlockSizeError" ],
     [ "Combination", "classgko_1_1Combination.html", "classgko_1_1Combination" ],
     [ "Composition", "classgko_1_1Composition.html", "classgko_1_1Composition" ],
-    [ "ConvertibleTo", "classgko_1_1ConvertibleTo.html", "classgko_1_1ConvertibleTo" ],
-    [ "CpuAllocator", "classgko_1_1CpuAllocator.html", null ],
-    [ "CpuAllocatorBase", "classgko_1_1CpuAllocatorBase.html", null ],
-    [ "CpuTimer", "classgko_1_1CpuTimer.html", "classgko_1_1CpuTimer" ],
-    [ "cpx_real_type", "structgko_1_1cpx__real__type.html", "structgko_1_1cpx__real__type" ],
-    [ "CublasError", "classgko_1_1CublasError.html", "classgko_1_1CublasError" ],
-    [ "cuda_stream", "classgko_1_1cuda__stream.html", "classgko_1_1cuda__stream" ],
-    [ "CudaAllocator", "classgko_1_1CudaAllocator.html", null ],
-    [ "CudaAllocatorBase", "classgko_1_1CudaAllocatorBase.html", null ],
-    [ "CudaAsyncAllocator", "classgko_1_1CudaAsyncAllocator.html", "classgko_1_1CudaAsyncAllocator" ],
+    [ "UseComposition", "classgko_1_1UseComposition.html", "classgko_1_1UseComposition" ],
+    [ "nvidia_device", "classgko_1_1nvidia__device.html", null ],
+    [ "amd_device", "classgko_1_1amd__device.html", null ],
+    [ "device_matrix_data", "classgko_1_1device__matrix__data.html", "classgko_1_1device__matrix__data" ],
+    [ "dim", "structgko_1_1dim.html", "structgko_1_1dim" ],
+    [ "dim&lt; 1u, DimensionType &gt;", "structgko_1_1dim_3_011u_00_01DimensionType_01_4.html", null ],
+    [ "Error", "classgko_1_1Error.html", "classgko_1_1Error" ],
+    [ "NotImplemented", "classgko_1_1NotImplemented.html", "classgko_1_1NotImplemented" ],
+    [ "NotCompiled", "classgko_1_1NotCompiled.html", "classgko_1_1NotCompiled" ],
+    [ "NotSupported", "classgko_1_1NotSupported.html", "classgko_1_1NotSupported" ],
+    [ "MpiError", "classgko_1_1MpiError.html", "classgko_1_1MpiError" ],
     [ "CudaError", "classgko_1_1CudaError.html", "classgko_1_1CudaError" ],
-    [ "CudaExecutor", "classgko_1_1CudaExecutor.html", "classgko_1_1CudaExecutor" ],
-    [ "CudaHostAllocator", "classgko_1_1CudaHostAllocator.html", null ],
-    [ "CudaTimer", "classgko_1_1CudaTimer.html", "classgko_1_1CudaTimer" ],
-    [ "CudaUnifiedAllocator", "classgko_1_1CudaUnifiedAllocator.html", null ],
-    [ "CufftError", "classgko_1_1CufftError.html", "classgko_1_1CufftError" ],
+    [ "CublasError", "classgko_1_1CublasError.html", "classgko_1_1CublasError" ],
     [ "CurandError", "classgko_1_1CurandError.html", "classgko_1_1CurandError" ],
     [ "CusparseError", "classgko_1_1CusparseError.html", "classgko_1_1CusparseError" ],
-    [ "default_converter", "structgko_1_1default__converter.html", "structgko_1_1default__converter" ],
-    [ "deferred_factory_parameter", "classgko_1_1deferred__factory__parameter.html", "classgko_1_1deferred__factory__parameter" ],
-    [ "device_matrix_data", "classgko_1_1device__matrix__data.html", "classgko_1_1device__matrix__data" ],
-    [ "DiagonalExtractable", "classgko_1_1DiagonalExtractable.html", "classgko_1_1DiagonalExtractable" ],
-    [ "DiagonalLinOpExtractable", "classgko_1_1DiagonalLinOpExtractable.html", "classgko_1_1DiagonalLinOpExtractable" ],
-    [ "dim", "structgko_1_1dim.html", "structgko_1_1dim" ],
-    [ "dim< 1u, DimensionType >", "structgko_1_1dim_3_011u_00_01DimensionType_01_4.html", null ],
-    [ "DimensionMismatch", "classgko_1_1DimensionMismatch.html", "classgko_1_1DimensionMismatch" ],
-    [ "DpcppExecutor", "classgko_1_1DpcppExecutor.html", "classgko_1_1DpcppExecutor" ],
-    [ "DpcppTimer", "classgko_1_1DpcppTimer.html", "classgko_1_1DpcppTimer" ],
-    [ "enable_parameters_type", "classgko_1_1enable__parameters__type.html", "classgko_1_1enable__parameters__type" ],
-    [ "EnableAbsoluteComputation", "classgko_1_1EnableAbsoluteComputation.html", "classgko_1_1EnableAbsoluteComputation" ],
-    [ "EnableAbstractPolymorphicObject", "classgko_1_1EnableAbstractPolymorphicObject.html", null ],
-    [ "EnableCreateMethod", "classgko_1_1EnableCreateMethod.html", null ],
-    [ "EnableDefaultFactory", "classgko_1_1EnableDefaultFactory.html", "classgko_1_1EnableDefaultFactory" ],
-    [ "EnableLinOp", "classgko_1_1EnableLinOp.html", null ],
-    [ "EnablePolymorphicAssignment", "classgko_1_1EnablePolymorphicAssignment.html", null ],
-    [ "EnablePolymorphicObject", "classgko_1_1EnablePolymorphicObject.html", null ],
-    [ "err", "structgko_1_1err.html", null ],
-    [ "Error", "classgko_1_1Error.html", "classgko_1_1Error" ],
-    [ "Executor", "classgko_1_1Executor.html", "classgko_1_1Executor" ],
-    [ "executor_deleter", "classgko_1_1executor__deleter.html", "classgko_1_1executor__deleter" ],
-    [ "executor_deleter< T[]>", "classgko_1_1executor__deleter_3_01T_0f_0e_4.html", null ],
-    [ "half", "classgko_1_1half.html", null ],
-    [ "hip_stream", "classgko_1_1hip__stream.html", "classgko_1_1hip__stream" ],
-    [ "HipAllocator", "classgko_1_1HipAllocator.html", null ],
-    [ "HipAllocatorBase", "classgko_1_1HipAllocatorBase.html", null ],
-    [ "HipAsyncAllocator", "classgko_1_1HipAsyncAllocator.html", null ],
-    [ "HipblasError", "classgko_1_1HipblasError.html", "classgko_1_1HipblasError" ],
+    [ "CufftError", "classgko_1_1CufftError.html", "classgko_1_1CufftError" ],
     [ "HipError", "classgko_1_1HipError.html", "classgko_1_1HipError" ],
-    [ "HipExecutor", "classgko_1_1HipExecutor.html", "classgko_1_1HipExecutor" ],
-    [ "HipfftError", "classgko_1_1HipfftError.html", "classgko_1_1HipfftError" ],
-    [ "HipHostAllocator", "classgko_1_1HipHostAllocator.html", null ],
+    [ "HipblasError", "classgko_1_1HipblasError.html", "classgko_1_1HipblasError" ],
     [ "HiprandError", "classgko_1_1HiprandError.html", "classgko_1_1HiprandError" ],
     [ "HipsparseError", "classgko_1_1HipsparseError.html", "classgko_1_1HipsparseError" ],
-    [ "HipTimer", "classgko_1_1HipTimer.html", "classgko_1_1HipTimer" ],
-    [ "HipUnifiedAllocator", "classgko_1_1HipUnifiedAllocator.html", null ],
-    [ "index_set", "classgko_1_1index__set.html", "classgko_1_1index__set" ],
-    [ "InvalidStateError", "classgko_1_1InvalidStateError.html", "classgko_1_1InvalidStateError" ],
-    [ "KernelNotFound", "classgko_1_1KernelNotFound.html", "classgko_1_1KernelNotFound" ],
-    [ "LinOp", "classgko_1_1LinOp.html", "classgko_1_1LinOp" ],
-    [ "LinOpFactory", "classgko_1_1LinOpFactory.html", null ],
-    [ "machine_topology", "classgko_1_1machine__topology.html", "classgko_1_1machine__topology" ],
-    [ "matrix_assembly_data", "classgko_1_1matrix__assembly__data.html", "classgko_1_1matrix__assembly__data" ],
-    [ "matrix_data", "structgko_1_1matrix__data.html", "structgko_1_1matrix__data" ],
-    [ "matrix_data_entry", "structgko_1_1matrix__data__entry.html", null ],
+    [ "HipfftError", "classgko_1_1HipfftError.html", "classgko_1_1HipfftError" ],
     [ "MetisError", "classgko_1_1MetisError.html", "classgko_1_1MetisError" ],
-    [ "MpiError", "classgko_1_1MpiError.html", "classgko_1_1MpiError" ],
-    [ "NotCompiled", "classgko_1_1NotCompiled.html", "classgko_1_1NotCompiled" ],
-    [ "NotImplemented", "classgko_1_1NotImplemented.html", "classgko_1_1NotImplemented" ],
-    [ "NotSupported", "classgko_1_1NotSupported.html", "classgko_1_1NotSupported" ],
-    [ "null_deleter", "classgko_1_1null__deleter.html", "classgko_1_1null__deleter" ],
-    [ "null_deleter< T[]>", "classgko_1_1null__deleter_3_01T_0f_0e_4.html", null ],
-    [ "nvidia_device", "classgko_1_1nvidia__device.html", null ],
-    [ "OmpExecutor", "classgko_1_1OmpExecutor.html", "classgko_1_1OmpExecutor" ],
-    [ "Operation", "classgko_1_1Operation.html", "classgko_1_1Operation" ],
+    [ "DimensionMismatch", "classgko_1_1DimensionMismatch.html", "classgko_1_1DimensionMismatch" ],
+    [ "BadDimension", "classgko_1_1BadDimension.html", "classgko_1_1BadDimension" ],
+    [ "BlockSizeError", "classgko_1_1BlockSizeError.html", "classgko_1_1BlockSizeError" ],
+    [ "ValueMismatch", "classgko_1_1ValueMismatch.html", "classgko_1_1ValueMismatch" ],
+    [ "AllocationError", "classgko_1_1AllocationError.html", "classgko_1_1AllocationError" ],
     [ "OutOfBoundsError", "classgko_1_1OutOfBoundsError.html", "classgko_1_1OutOfBoundsError" ],
     [ "OverflowError", "classgko_1_1OverflowError.html", "classgko_1_1OverflowError" ],
+    [ "StreamError", "classgko_1_1StreamError.html", "classgko_1_1StreamError" ],
+    [ "KernelNotFound", "classgko_1_1KernelNotFound.html", "classgko_1_1KernelNotFound" ],
+    [ "UnsupportedMatrixProperty", "classgko_1_1UnsupportedMatrixProperty.html", "classgko_1_1UnsupportedMatrixProperty" ],
+    [ "InvalidStateError", "classgko_1_1InvalidStateError.html", "classgko_1_1InvalidStateError" ],
+    [ "Operation", "classgko_1_1Operation.html", "classgko_1_1Operation" ],
+    [ "Executor", "classgko_1_1Executor.html", "classgko_1_1Executor" ],
+    [ "executor_deleter", "classgko_1_1executor__deleter.html", "classgko_1_1executor__deleter" ],
+    [ "executor_deleter&lt; T[]&gt;", "classgko_1_1executor__deleter_3_01T_0f_0e_4.html", null ],
+    [ "OmpExecutor", "classgko_1_1OmpExecutor.html", "classgko_1_1OmpExecutor" ],
+    [ "ReferenceExecutor", "classgko_1_1ReferenceExecutor.html", "classgko_1_1ReferenceExecutor" ],
+    [ "CudaExecutor", "classgko_1_1CudaExecutor.html", "classgko_1_1CudaExecutor" ],
+    [ "HipExecutor", "classgko_1_1HipExecutor.html", "classgko_1_1HipExecutor" ],
+    [ "DpcppExecutor", "classgko_1_1DpcppExecutor.html", "classgko_1_1DpcppExecutor" ],
+    [ "truncated", "classgko_1_1truncated.html", null ],
+    [ "half", "classgko_1_1half.html", null ],
+    [ "index_set", "classgko_1_1index__set.html", "classgko_1_1index__set" ],
+    [ "LinOp", "classgko_1_1LinOp.html", "classgko_1_1LinOp" ],
+    [ "LinOpFactory", "classgko_1_1LinOpFactory.html", null ],
+    [ "Transposable", "classgko_1_1Transposable.html", "classgko_1_1Transposable" ],
     [ "Permutable", "classgko_1_1Permutable.html", "classgko_1_1Permutable" ],
+    [ "ReadableFromMatrixData", "classgko_1_1ReadableFromMatrixData.html", "classgko_1_1ReadableFromMatrixData" ],
+    [ "WritableToMatrixData", "classgko_1_1WritableToMatrixData.html", "classgko_1_1WritableToMatrixData" ],
+    [ "Preconditionable", "classgko_1_1Preconditionable.html", "classgko_1_1Preconditionable" ],
+    [ "DiagonalLinOpExtractable", "classgko_1_1DiagonalLinOpExtractable.html", "classgko_1_1DiagonalLinOpExtractable" ],
+    [ "DiagonalExtractable", "classgko_1_1DiagonalExtractable.html", "classgko_1_1DiagonalExtractable" ],
+    [ "AbsoluteComputable", "classgko_1_1AbsoluteComputable.html", "classgko_1_1AbsoluteComputable" ],
+    [ "EnableAbsoluteComputation", "classgko_1_1EnableAbsoluteComputation.html", "classgko_1_1EnableAbsoluteComputation" ],
+    [ "ScaledIdentityAddable", "classgko_1_1ScaledIdentityAddable.html", "classgko_1_1ScaledIdentityAddable" ],
+    [ "EnableLinOp", "classgko_1_1EnableLinOp.html", null ],
+    [ "machine_topology", "classgko_1_1machine__topology.html", "classgko_1_1machine__topology" ],
+    [ "cpx_real_type", "structgko_1_1cpx__real__type.html", "structgko_1_1cpx__real__type" ],
+    [ "default_converter", "structgko_1_1default__converter.html", "structgko_1_1default__converter" ],
+    [ "matrix_assembly_data", "classgko_1_1matrix__assembly__data.html", "classgko_1_1matrix__assembly__data" ],
+    [ "matrix_data_entry", "structgko_1_1matrix__data__entry.html", null ],
+    [ "matrix_data", "structgko_1_1matrix__data.html", "structgko_1_1matrix__data" ],
+    [ "Allocator", "classgko_1_1Allocator.html", null ],
+    [ "CpuAllocatorBase", "classgko_1_1CpuAllocatorBase.html", null ],
+    [ "CudaAllocatorBase", "classgko_1_1CudaAllocatorBase.html", null ],
+    [ "HipAllocatorBase", "classgko_1_1HipAllocatorBase.html", null ],
+    [ "CpuAllocator", "classgko_1_1CpuAllocator.html", null ],
+    [ "CudaAllocator", "classgko_1_1CudaAllocator.html", null ],
+    [ "CudaAsyncAllocator", "classgko_1_1CudaAsyncAllocator.html", "classgko_1_1CudaAsyncAllocator" ],
+    [ "CudaUnifiedAllocator", "classgko_1_1CudaUnifiedAllocator.html", null ],
+    [ "CudaHostAllocator", "classgko_1_1CudaHostAllocator.html", null ],
+    [ "HipAllocator", "classgko_1_1HipAllocator.html", null ],
+    [ "HipAsyncAllocator", "classgko_1_1HipAsyncAllocator.html", null ],
+    [ "HipUnifiedAllocator", "classgko_1_1HipUnifiedAllocator.html", null ],
+    [ "HipHostAllocator", "classgko_1_1HipHostAllocator.html", null ],
     [ "Perturbation", "classgko_1_1Perturbation.html", "classgko_1_1Perturbation" ],
     [ "PolymorphicObject", "classgko_1_1PolymorphicObject.html", "classgko_1_1PolymorphicObject" ],
-    [ "precision_reduction", "classgko_1_1precision__reduction.html", "classgko_1_1precision__reduction" ],
-    [ "Preconditionable", "classgko_1_1Preconditionable.html", "classgko_1_1Preconditionable" ],
-    [ "ptr_param", "classgko_1_1ptr__param.html", "classgko_1_1ptr__param" ],
+    [ "EnablePolymorphicObject", "classgko_1_1EnablePolymorphicObject.html", null ],
+    [ "EnablePolymorphicAssignment", "classgko_1_1EnablePolymorphicAssignment.html", null ],
+    [ "EnableCreateMethod", "classgko_1_1EnableCreateMethod.html", null ],
+    [ "span", "structgko_1_1span.html", "structgko_1_1span" ],
+    [ "local_span", "structgko_1_1local__span.html", "structgko_1_1local__span" ],
     [ "range", "classgko_1_1range.html", "classgko_1_1range" ],
-    [ "ReadableFromMatrixData", "classgko_1_1ReadableFromMatrixData.html", "classgko_1_1ReadableFromMatrixData" ],
-    [ "ReferenceExecutor", "classgko_1_1ReferenceExecutor.html", "classgko_1_1ReferenceExecutor" ],
-    [ "ScaledIdentityAddable", "classgko_1_1ScaledIdentityAddable.html", "classgko_1_1ScaledIdentityAddable" ],
     [ "scoped_device_id_guard", "classgko_1_1scoped__device__id__guard.html", "classgko_1_1scoped__device__id__guard" ],
     [ "segmented_array", "structgko_1_1segmented__array.html", "structgko_1_1segmented__array" ],
-    [ "span", "structgko_1_1span.html", "structgko_1_1span" ],
-    [ "stopping_status", "classgko_1_1stopping__status.html", "classgko_1_1stopping__status" ],
-    [ "StreamError", "classgko_1_1StreamError.html", "classgko_1_1StreamError" ],
+    [ "cuda_stream", "classgko_1_1cuda__stream.html", "classgko_1_1cuda__stream" ],
+    [ "hip_stream", "classgko_1_1hip__stream.html", "classgko_1_1hip__stream" ],
+    [ "err", "structgko_1_1err.html", null ],
     [ "time_point", "classgko_1_1time__point.html", null ],
     [ "Timer", "classgko_1_1Timer.html", "classgko_1_1Timer" ],
-    [ "Transposable", "classgko_1_1Transposable.html", "classgko_1_1Transposable" ],
-    [ "truncated", "classgko_1_1truncated.html", null ],
-    [ "UnsupportedMatrixProperty", "classgko_1_1UnsupportedMatrixProperty.html", "classgko_1_1UnsupportedMatrixProperty" ],
-    [ "UseComposition", "classgko_1_1UseComposition.html", "classgko_1_1UseComposition" ],
-    [ "ValueMismatch", "classgko_1_1ValueMismatch.html", "classgko_1_1ValueMismatch" ],
+    [ "CpuTimer", "classgko_1_1CpuTimer.html", "classgko_1_1CpuTimer" ],
+    [ "CudaTimer", "classgko_1_1CudaTimer.html", "classgko_1_1CudaTimer" ],
+    [ "HipTimer", "classgko_1_1HipTimer.html", "classgko_1_1HipTimer" ],
+    [ "DpcppTimer", "classgko_1_1DpcppTimer.html", "classgko_1_1DpcppTimer" ],
+    [ "are_all_integral", "structgko_1_1are__all__integral.html", null ],
+    [ "are_all_integral&lt; First, Args... &gt;", "structgko_1_1are__all__integral_3_01First_00_01Args_8_8_8_01_4.html", null ],
+    [ "precision_reduction", "classgko_1_1precision__reduction.html", "classgko_1_1precision__reduction" ],
+    [ "ptr_param", "classgko_1_1ptr__param.html", "classgko_1_1ptr__param" ],
+    [ "null_deleter", "classgko_1_1null__deleter.html", "classgko_1_1null__deleter" ],
+    [ "null_deleter&lt; T[]&gt;", "classgko_1_1null__deleter_3_01T_0f_0e_4.html", null ],
     [ "version", "structgko_1_1version.html", "structgko_1_1version" ],
     [ "version_info", "classgko_1_1version__info.html", "classgko_1_1version__info" ],
-    [ "WritableToMatrixData", "classgko_1_1WritableToMatrixData.html", "classgko_1_1WritableToMatrixData" ],
+    [ "stopping_status", "classgko_1_1stopping__status.html", "classgko_1_1stopping__status" ],
     [ "default_precision", "namespacegko.html#a89637c833af7ae805802226d97cebebf", null ],
     [ "EnableDefaultLinOpFactory", "group__LinOp.html#ga33a81667a26919fae5864bbd9ca302ad", null ],
     [ "float16", "namespacegko.html#af1e94db06aba818c1db32a2a683836c9", null ],
@@ -173,11 +172,7 @@ var namespacegko =
     [ "uint64", "namespacegko.html#a09ee89da532d8b1fa6fdecec2d20b9bf", null ],
     [ "uint8", "namespacegko.html#a06d96f1ecdca6b86399173969771c3fb", null ],
     [ "uintptr", "namespacegko.html#a70648f1299a0c1297e2bf86f47264626", null ],
-    [ "allocation_mode", "namespacegko.html#afbed8e2cbd3ee4ca962e12f688858bdb", [
-      [ "device", "namespacegko.html#afbed8e2cbd3ee4ca962e12f688858bdba913f9c49dcb544e2087cee284f4a00b7", null ],
-      [ "unified_global", "namespacegko.html#afbed8e2cbd3ee4ca962e12f688858bdba6710811180c946b52fa75ed391f68b30", null ],
-      [ "unified_host", "namespacegko.html#afbed8e2cbd3ee4ca962e12f688858bdbab8dbfff61518de20fe05a40247a70b48", null ]
-    ] ],
+    [ "allocation_mode", "namespacegko.html#afbed8e2cbd3ee4ca962e12f688858bdb", null ],
     [ "layout_type", "namespacegko.html#ae749a5ea11a93c1bcc9158d9a6e9fb68", [
       [ "array", "namespacegko.html#ae749a5ea11a93c1bcc9158d9a6e9fb68af1f713c9e000f5d3f280adbd124df4f5", null ],
       [ "coordinate", "namespacegko.html#ae749a5ea11a93c1bcc9158d9a6e9fb68af5d7aa3ba4929cc12dc51a92c59fabd3", null ]
@@ -198,6 +193,7 @@ var namespacegko =
     [ "clone", "namespacegko.html#aa194e34282452493231ca7b01ffb5e64", null ],
     [ "clone", "namespacegko.html#a7412910f84951c1a23563e758eb01282", null ],
     [ "conj", "namespacegko.html#ad79fd5c1fb85403796c40c0a916a15f2", null ],
+    [ "convert_to", "namespacegko.html#a7cb327baf9ca9018d06fa5554464d29d", null ],
     [ "copy_and_convert_to", "namespacegko.html#ae27269c18937d9a8866b431aff94433e", null ],
     [ "copy_and_convert_to", "namespacegko.html#ab6954ded2bc4730777068facde07983a", null ],
     [ "copy_and_convert_to", "namespacegko.html#a2c02ca75c7c97c556424bc2996510c83", null ],
@@ -213,14 +209,14 @@ var namespacegko =
     [ "invalid_index", "namespacegko.html#afec01a3afbf68d99fc0f886c51bdc713", null ],
     [ "is_complex", "namespacegko.html#a9b3e79911bb6145d7ba865dbe436b915", null ],
     [ "is_complex_or_scalar", "namespacegko.html#a6881ebae53e15cb88342c0540d953f59", null ],
-    [ "is_finite", "namespacegko.html#a01e4cc92b86977c60de3fe3ee991fa40", null ],
     [ "is_finite", "namespacegko.html#aafd1826b8d8325e5eadec7c9568dbc14", null ],
-    [ "is_nan", "namespacegko.html#a6f943e1343264921351afce70b33009a", null ],
+    [ "is_finite", "namespacegko.html#a01e4cc92b86977c60de3fe3ee991fa40", null ],
     [ "is_nan", "namespacegko.html#acff21f04b9f0d01bf5fc5d8da3d939e0", null ],
+    [ "is_nan", "namespacegko.html#a6f943e1343264921351afce70b33009a", null ],
     [ "is_nonzero", "namespacegko.html#aef9b29733e6eb45475a2b84f79a6d012", null ],
     [ "is_zero", "namespacegko.html#a785976e6dbc9d8511325617ca46040bf", null ],
-    [ "lend", "namespacegko.html#aa011422ea11684b8b3121058cd6f8933", null ],
     [ "lend", "namespacegko.html#acc4ed16c876310fd8cffaca4d6c62664", null ],
+    [ "lend", "namespacegko.html#aa011422ea11684b8b3121058cd6f8933", null ],
     [ "make_array_view", "namespacegko.html#a752922d291cf7c72e3042cc5b367aa60", null ],
     [ "make_const_array_view", "namespacegko.html#a5309c321872a54fc9818ed9f5556eef4", null ],
     [ "make_const_dense_view", "namespacegko.html#a218d2e44e2d95fbe638ad98789fccb07", null ],
@@ -232,8 +228,9 @@ var namespacegko =
     [ "min", "namespacegko.html#aaaf8487194bcb40b528969c187a413a0", null ],
     [ "mixed_precision_dispatch", "namespacegko.html#a205901dcce27e1df970c569d46d87551", null ],
     [ "mixed_precision_dispatch_real_complex", "namespacegko.html#a3b9785eed86179e15b8fb4e74f7e9f89", null ],
-    [ "nan", "namespacegko.html#a70bf9f2c62b689f4f7e074392be0f828", null ],
+    [ "move_to", "namespacegko.html#a6fcc3453bf500454b56a5f2f196b871c", null ],
     [ "nan", "namespacegko.html#a2d8c25cb4bc4a661a986b5cae340c96b", null ],
+    [ "nan", "namespacegko.html#a70bf9f2c62b689f4f7e074392be0f828", null ],
     [ "one", "namespacegko.html#a0059e27f8f4bc348ff65c1e60caf47c8", null ],
     [ "one", "namespacegko.html#ab4f16ecf0a759f46259cf9518f1e4568", null ],
     [ "operator!=", "namespacegko.html#accf6e6291e57abe8d7d05968666a42e0", null ],
@@ -265,7 +262,8 @@ var namespacegko =
     [ "transpose", "namespacegko.html#a471f1b79842d9b7e2e97d10d2eef5fee", null ],
     [ "unit_root", "namespacegko.html#a7d18aa213befc4d1dac5dbc8eeed6e7d", null ],
     [ "with_matrix_type", "namespacegko.html#a537803d962d07cf43e1e0cbc9f6a3f8b", null ],
-    [ "write", "namespacegko.html#a82d427878e771fc00144d6d2dd4f4e64", null ],
+    [ "write", "namespacegko.html#abc28c235c3fbbf3c495b1850c61746d2", null ],
+    [ "write", "namespacegko.html#af82d8f7795fefcf5f38a38895e316c02", null ],
     [ "write_binary", "namespacegko.html#aba9ca89ef08421197d3dbf84b0ad884c", null ],
     [ "write_binary_raw", "namespacegko.html#a3b27a0c0282115116c160884dc0a9468", null ],
     [ "write_raw", "namespacegko.html#a2d4b63ce98a16dc2c48aacd534a7b8ba", null ],
