@@ -1,17 +1,14 @@
 var namespacegko_1_1experimental_1_1distributed =
 [
     [ "preconditioner", "namespacegko_1_1experimental_1_1distributed_1_1preconditioner.html", "namespacegko_1_1experimental_1_1distributed_1_1preconditioner" ],
+    [ "Partition", "classgko_1_1experimental_1_1distributed_1_1Partition.html", "classgko_1_1experimental_1_1distributed_1_1Partition" ],
     [ "DistributedBase", "classgko_1_1experimental_1_1distributed_1_1DistributedBase.html", "classgko_1_1experimental_1_1distributed_1_1DistributedBase" ],
     [ "index_map", "classgko_1_1experimental_1_1distributed_1_1index__map.html", "classgko_1_1experimental_1_1distributed_1_1index__map" ],
-    [ "Matrix", "classgko_1_1experimental_1_1distributed_1_1Matrix.html", "classgko_1_1experimental_1_1distributed_1_1Matrix" ],
-    [ "Partition", "classgko_1_1experimental_1_1distributed_1_1Partition.html", "classgko_1_1experimental_1_1distributed_1_1Partition" ],
-    [ "RowGatherer", "classgko_1_1experimental_1_1distributed_1_1RowGatherer.html", "classgko_1_1experimental_1_1distributed_1_1RowGatherer" ],
     [ "Vector", "classgko_1_1experimental_1_1distributed_1_1Vector.html", "classgko_1_1experimental_1_1distributed_1_1Vector" ],
+    [ "Matrix", "classgko_1_1experimental_1_1distributed_1_1Matrix.html", "classgko_1_1experimental_1_1distributed_1_1Matrix" ],
+    [ "RowGatherer", "classgko_1_1experimental_1_1distributed_1_1RowGatherer.html", "classgko_1_1experimental_1_1distributed_1_1RowGatherer" ],
     [ "comm_index_type", "namespacegko_1_1experimental_1_1distributed.html#a13b7760affb031fee59d385754eaaffb", null ],
-    [ "assembly_mode", "namespacegko_1_1experimental_1_1distributed.html#a4b66bc2bbe95fe0a818a5f4423acbb4e", [
-      [ "communicate", "namespacegko_1_1experimental_1_1distributed.html#a4b66bc2bbe95fe0a818a5f4423acbb4ea01b922d867dfc910199b04faca436f37", null ],
-      [ "local_only", "namespacegko_1_1experimental_1_1distributed.html#a4b66bc2bbe95fe0a818a5f4423acbb4ea4f2603689acfa6e2968100b353bbb547", null ]
-    ] ],
+    [ "assembly_mode", "namespacegko_1_1experimental_1_1distributed.html#a4b66bc2bbe95fe0a818a5f4423acbb4e", null ],
     [ "index_space", "namespacegko_1_1experimental_1_1distributed.html#a3d50932cfebdde844b88d2c82b96947b", [
       [ "local", "namespacegko_1_1experimental_1_1distributed.html#a3d50932cfebdde844b88d2c82b96947baf5ddaf0ca7929578b408c909429f68f2", null ],
       [ "non_local", "namespacegko_1_1experimental_1_1distributed.html#a3d50932cfebdde844b88d2c82b96947ba9182221a9ec0a65321d5a206c9c174ca", null ],
