@@ -1,7 +1,7 @@
 var namespacegko_1_1multigrid =
 [
-    [ "EnableMultigridLevel", "classgko_1_1multigrid_1_1EnableMultigridLevel.html", "classgko_1_1multigrid_1_1EnableMultigridLevel" ],
+    [ "Pgm", "classgko_1_1multigrid_1_1Pgm.html", "classgko_1_1multigrid_1_1Pgm" ],
     [ "FixedCoarsening", "classgko_1_1multigrid_1_1FixedCoarsening.html", "classgko_1_1multigrid_1_1FixedCoarsening" ],
     [ "MultigridLevel", "classgko_1_1multigrid_1_1MultigridLevel.html", "classgko_1_1multigrid_1_1MultigridLevel" ],
-    [ "Pgm", "classgko_1_1multigrid_1_1Pgm.html", "classgko_1_1multigrid_1_1Pgm" ]
+    [ "EnableMultigridLevel", "classgko_1_1multigrid_1_1EnableMultigridLevel.html", "classgko_1_1multigrid_1_1EnableMultigridLevel" ]
 ];
\ No newline at end of file
