@@ -129,14 +129,12 @@ var NAVTREE =
     [ "Citing Ginkgo", "citing_ginkgo.html", null ],
     [ "Example programs", "Examples.html", null ],
     [ "The adaptiveprecision-blockjacobi program", "adaptiveprecision_blockjacobi.html", null ],
-    [ "The batched-solver program", "batched_solver.html", null ],
     [ "The cb-gmres program", "cb_gmres.html", null ],
     [ "The custom-logger program", "custom_logger.html", null ],
     [ "The custom-matrix-format program", "custom_matrix_format.html", null ],
     [ "The custom-stopping-criterion program", "custom_stopping_criterion.html", null ],
     [ "The distributed-multigrid-preconditioned-solver program", "distributed_multigrid_preconditioned_solver.html", null ],
     [ "The distributed-solver program", "distributed_solver.html", null ],
-    [ "The external-lib-interfacing program", "external_lib_interfacing.html", null ],
     [ "The file-config-solver program", "file_config_solver.html", null ],
     [ "The ginkgo-overhead program", "ginkgo_overhead.html", null ],
     [ "The ginkgo-ranges program", "ginkgo_ranges.html", null ],
@@ -175,15 +173,15 @@ var NAVTREE =
 var NAVTREEINDEX =
 [
 "Examples.html",
-"classgko_1_1NotCompiled.html#aa85feba061f17a192a47f238a5bb4a32",
-"classgko_1_1config_1_1pnode.html#a3b5eac91e5865801b16dd346b47fa0d2",
-"classgko_1_1experimental_1_1mpi_1_1DenseCommunicator.html#a33a2a971df99faf4fb41940a79720691",
-"classgko_1_1experimental_1_1reorder_1_1Rcm.html#a1dc8890f88e6a7786a10ad93d40fb06d",
-"classgko_1_1log_1_1profiling__scope__guard.html#af73538d396030074e0840682420433c6",
-"contributing_guidelines.html#autotoc_md57",
-"namespacegko.html#a5e379ed0d74e7c7f8c33fbfe6816e697",
-"simple_solver.html",
-"structgko_1_1log_1_1linop__data.html"
+"classgko_1_1OutOfBoundsError.html",
+"classgko_1_1config_1_1pnode.html#addfffdf67c06309a6cf6d1e9edbe8b0a",
+"classgko_1_1experimental_1_1mpi_1_1NeighborhoodCommunicator.html",
+"classgko_1_1hip__stream.html#adbbf3251c2e50ae1430ebd2dcb77c0d9",
+"classgko_1_1machine__topology.html#afd8db0ad172e7aa0727a2f22c6f6eb51",
+"device__matrix__data_8hpp_source.html",
+"namespacegko.html#a89637c833af7ae805802226d97cebebf",
+"structgko_1_1accessor_1_1less.html",
+"structgko_1_1reorder_1_1Rcm_1_1parameters__type.html#a4c30f0388851e1dc03a7bf0d243fae24"
 ];
 
 var SYNCONMSG = 'click to disable panel synchronization';
