@@ -18,15 +18,13 @@ var searchData=
   ['index_5fmap_3c_20local_5findex_5ftype_2c_20global_5findex_5ftype_20_3e_15',['index_map&lt; local_index_type, global_index_type &gt;',['../classgko_1_1experimental_1_1distributed_1_1index__map.html',1,'gko::experimental::distributed']]],
   ['index_5fset_16',['index_set',['../classgko_1_1index__set.html',1,'gko']]],
   ['invalidstateerror_17',['InvalidStateError',['../classgko_1_1InvalidStateError.html',1,'gko']]],
-  ['ir_18',['Ir',['../classgko_1_1solver_1_1Ir.html',1,'gko::solver']]],
-  ['ir_3c_20valuetype_20_3e_19',['Ir&lt; ValueType &gt;',['../classgko_1_1solver_1_1Ir.html',1,'gko::solver']]],
-  ['isai_20',['Isai',['../classgko_1_1preconditioner_1_1Isai.html',1,'gko::preconditioner']]],
-  ['isai_3c_20isai_5ftype_3a_3ageneral_2c_20valuetype_2c_20indextype_20_3e_21',['Isai&lt; isai_type::general, ValueType, IndexType &gt;',['../classgko_1_1preconditioner_1_1Isai.html',1,'gko::preconditioner']]],
-  ['isai_3c_20isai_5ftype_3a_3alower_2c_20valuetype_2c_20indextype_20_3e_22',['Isai&lt; isai_type::lower, ValueType, IndexType &gt;',['../classgko_1_1preconditioner_1_1Isai.html',1,'gko::preconditioner']]],
-  ['isai_3c_20isai_5ftype_3a_3aspd_2c_20valuetype_2c_20indextype_20_3e_23',['Isai&lt; isai_type::spd, ValueType, IndexType &gt;',['../classgko_1_1preconditioner_1_1Isai.html',1,'gko::preconditioner']]],
-  ['isai_3c_20isai_5ftype_3a_3aupper_2c_20valuetype_2c_20indextype_20_3e_24',['Isai&lt; isai_type::upper, ValueType, IndexType &gt;',['../classgko_1_1preconditioner_1_1Isai.html',1,'gko::preconditioner']]],
-  ['isai_3c_20isaitype_3d_3disai_5ftype_3a_3ageneral_20_3f_20isai_5ftype_3a_3ageneral_20_3aisaitype_3d_3disai_5ftype_3a_3aspd_20_3f_20isai_5ftype_3a_3aspd_20_3aisaitype_3d_3disai_5ftype_3a_3alower_20_3f_20isai_5ftype_3a_3aupper_20_3aisai_5ftype_3a_3alower_2c_20valuetype_2c_20indextype_20_3e_25',['Isai&lt; IsaiType==isai_type::general ? isai_type::general :IsaiType==isai_type::spd ? isai_type::spd :IsaiType==isai_type::lower ? isai_type::upper :isai_type::lower, ValueType, IndexType &gt;',['../classgko_1_1preconditioner_1_1Isai.html',1,'gko::preconditioner']]],
-  ['iteration_26',['Iteration',['../classgko_1_1stop_1_1Iteration.html',1,'gko::stop']]],
-  ['iteration_5fcomplete_5fdata_27',['iteration_complete_data',['../structgko_1_1log_1_1iteration__complete__data.html',1,'gko::log']]],
-  ['iterativebase_28',['IterativeBase',['../classgko_1_1solver_1_1IterativeBase.html',1,'gko::solver']]]
+  ['isai_18',['Isai',['../classgko_1_1preconditioner_1_1Isai.html',1,'gko::preconditioner']]],
+  ['isai_3c_20isai_5ftype_3a_3ageneral_2c_20valuetype_2c_20indextype_20_3e_19',['Isai&lt; isai_type::general, ValueType, IndexType &gt;',['../classgko_1_1preconditioner_1_1Isai.html',1,'gko::preconditioner']]],
+  ['isai_3c_20isai_5ftype_3a_3alower_2c_20valuetype_2c_20indextype_20_3e_20',['Isai&lt; isai_type::lower, ValueType, IndexType &gt;',['../classgko_1_1preconditioner_1_1Isai.html',1,'gko::preconditioner']]],
+  ['isai_3c_20isai_5ftype_3a_3aspd_2c_20valuetype_2c_20indextype_20_3e_21',['Isai&lt; isai_type::spd, ValueType, IndexType &gt;',['../classgko_1_1preconditioner_1_1Isai.html',1,'gko::preconditioner']]],
+  ['isai_3c_20isai_5ftype_3a_3aupper_2c_20valuetype_2c_20indextype_20_3e_22',['Isai&lt; isai_type::upper, ValueType, IndexType &gt;',['../classgko_1_1preconditioner_1_1Isai.html',1,'gko::preconditioner']]],
+  ['isai_3c_20isaitype_3d_3disai_5ftype_3a_3ageneral_20_3f_20isai_5ftype_3a_3ageneral_20_3aisaitype_3d_3disai_5ftype_3a_3aspd_20_3f_20isai_5ftype_3a_3aspd_20_3aisaitype_3d_3disai_5ftype_3a_3alower_20_3f_20isai_5ftype_3a_3aupper_20_3aisai_5ftype_3a_3alower_2c_20valuetype_2c_20indextype_20_3e_23',['Isai&lt; IsaiType==isai_type::general ? isai_type::general :IsaiType==isai_type::spd ? isai_type::spd :IsaiType==isai_type::lower ? isai_type::upper :isai_type::lower, ValueType, IndexType &gt;',['../classgko_1_1preconditioner_1_1Isai.html',1,'gko::preconditioner']]],
+  ['iteration_24',['Iteration',['../classgko_1_1stop_1_1Iteration.html',1,'gko::stop']]],
+  ['iteration_5fcomplete_5fdata_25',['iteration_complete_data',['../structgko_1_1log_1_1iteration__complete__data.html',1,'gko::log']]],
+  ['iterativebase_26',['IterativeBase',['../classgko_1_1solver_1_1IterativeBase.html',1,'gko::solver']]]
 ];
