@@ -24,5 +24,7 @@ var searchData=
   ['mul_21',['mul',['../structgko_1_1accessor_1_1mul.html',1,'gko::accessor']]],
   ['multigrid_22',['Multigrid',['../classgko_1_1solver_1_1Multigrid.html',1,'gko::solver']]],
   ['multigridlevel_23',['MultigridLevel',['../classgko_1_1multigrid_1_1MultigridLevel.html',1,'gko::multigrid']]],
-  ['multivector_24',['MultiVector',['../classgko_1_1batch_1_1MultiVector.html',1,'gko::batch']]]
+  ['multiply_5fadd_5freuse_5finfo_24',['multiply_add_reuse_info',['../classgko_1_1matrix_1_1Csr_1_1multiply__add__reuse__info.html',1,'gko::matrix::Csr']]],
+  ['multiply_5freuse_5finfo_25',['multiply_reuse_info',['../classgko_1_1matrix_1_1Csr_1_1multiply__reuse__info.html',1,'gko::matrix::Csr']]],
+  ['multivector_26',['MultiVector',['../classgko_1_1batch_1_1MultiVector.html',1,'gko::batch']]]
 ];
