@@ -6,7 +6,7 @@ var searchData=
   ['unpack_3',['unpack',['../classgko_1_1experimental_1_1factorization_1_1Factorization.html#ad0163a75274ff8054cc4d93732d82501',1,'gko::experimental::factorization::Factorization']]],
   ['unsupportedmatrixproperty_4',['UnsupportedMatrixProperty',['../classgko_1_1UnsupportedMatrixProperty.html#a38d858283d1e7e4a852c93baf79e7217',1,'gko::UnsupportedMatrixProperty']]],
   ['update_5',['update',['../classgko_1_1stop_1_1Criterion.html#a47e22c46eaa742d709dcbf0d26d93e6c',1,'gko::stop::Criterion']]],
-  ['update_5fvalues_6',['update_values',['../structgko_1_1matrix_1_1Csr_1_1permuting__reuse__info.html#a335568a4da6c11cff5dc7adbd347b4ce',1,'gko::matrix::Csr::permuting_reuse_info']]],
+  ['update_5fvalues_6',['update_values',['../classgko_1_1matrix_1_1Csr_1_1multiply__reuse__info.html#aa8b9bb2b8ffc1e345663c4780897ed79',1,'gko::matrix::Csr::multiply_reuse_info::update_values()'],['../classgko_1_1matrix_1_1Csr_1_1multiply__add__reuse__info.html#a97921c3b4c3005a51e5a3fc91978f6c2',1,'gko::matrix::Csr::multiply_add_reuse_info::update_values()'],['../classgko_1_1matrix_1_1Csr_1_1scale__add__reuse__info.html#a966159aa1adb984d1b274e30a022a17c',1,'gko::matrix::Csr::scale_add_reuse_info::update_values()'],['../structgko_1_1matrix_1_1Csr_1_1permuting__reuse__info.html#a335568a4da6c11cff5dc7adbd347b4ce',1,'gko::matrix::Csr::permuting_reuse_info::update_values()']]],
   ['updater_7',['Updater',['../classgko_1_1stop_1_1Criterion_1_1Updater.html#aa8356e2fbfaf46cab62d8f8a905ab8bd',1,'gko::stop::Criterion::Updater']]],
   ['uppertrs_8',['UpperTrs',['../classgko_1_1solver_1_1UpperTrs.html#a9fc8a602b284e8923b6a30135c84c437',1,'gko::solver::UpperTrs::UpperTrs(const UpperTrs &amp;)'],['../classgko_1_1solver_1_1UpperTrs.html#a97322e2b1e6bcce67f074f7fc5dd7cd1',1,'gko::solver::UpperTrs::UpperTrs(UpperTrs &amp;&amp;)']]],
   ['user_5frange_9',['user_range',['../classgko_1_1log_1_1ProfilerHook.html#a4d0e1e93d993f5074d60276359faadd8',1,'gko::log::ProfilerHook']]]
