@@ -11,6 +11,5 @@ var searchData=
   ['examples_8',['Documenting examples',['../contributing_guidelines.html#autotoc_md62',1,'']]],
   ['executors_20in_20ginkgo_9',['Executors in Ginkgo.',['../group__Executor.html#exec_1',1,'']]],
   ['export_20program_10',['The preconditioner-export program',['../preconditioner_export.html',1,'']]],
-  ['extended_20header_20files_11',['Extended header files',['../contributing_guidelines.html#autotoc_md21',1,'']]],
-  ['external_20lib_20interfacing_20program_12',['The external-lib-interfacing program',['../external_lib_interfacing.html',1,'']]]
+  ['extended_20header_20files_11',['Extended header files',['../contributing_guidelines.html#autotoc_md21',1,'']]]
 ];
