@@ -2,7 +2,7 @@ var searchData=
 [
   ['generated_5flocal_5fsolver_0',['generated_local_solver',['../structgko_1_1experimental_1_1distributed_1_1preconditioner_1_1Schwarz_1_1parameters__type.html#a6fb14b36a6cfc1b42e98ab01bfac9e08',1,'gko::experimental::distributed::preconditioner::Schwarz::parameters_type']]],
   ['generated_5fpreconditioner_1',['generated_preconditioner',['../structgko_1_1batch_1_1solver_1_1enable__preconditioned__iterative__solver__factory__parameters.html#ab9b3bdf2d54eecbfb9c322e3e4289295',1,'gko::batch::solver::enable_preconditioned_iterative_solver_factory_parameters::generated_preconditioner'],['../structgko_1_1solver_1_1enable__preconditioned__iterative__solver__factory__parameters.html#a7765c24219826716fd9be54b9a068f2e',1,'gko::solver::enable_preconditioned_iterative_solver_factory_parameters::generated_preconditioner']]],
-  ['generated_5fsolver_2',['generated_solver',['../structgko_1_1solver_1_1Ir_1_1parameters__type.html#a815bee91294da4c35a9216638743bf16',1,'gko::solver::Ir::parameters_type']]],
+  ['generated_5fsolver_2',['generated_solver',['../structgko_1_1solver_1_1parameters__type.html#a57a0aa04756adc0d2335b609409ca9b2',1,'gko::solver::parameters_type']]],
   ['group_5foffset_3',['group_offset',['../structgko_1_1preconditioner_1_1block__interleaved__storage__scheme.html#aa8a6723ef709e69bda55eaabaeee582e',1,'gko::preconditioner::block_interleaved_storage_scheme']]],
   ['group_5fpower_4',['group_power',['../structgko_1_1preconditioner_1_1block__interleaved__storage__scheme.html#a8fa279f4178c767bdbf52ef4d7e23ad1',1,'gko::preconditioner::block_interleaved_storage_scheme']]]
 ];
