@@ -2,7 +2,7 @@ var searchData=
 [
   ['reduction_5ffactor_0',['reduction_factor',['../structgko_1_1stop_1_1ResidualNorm_1_1parameters__type.html#a4b21f43cb4c33dd4b41e0e687bab5089',1,'gko::stop::ResidualNorm::parameters_type::reduction_factor'],['../structgko_1_1stop_1_1ImplicitResidualNorm_1_1parameters__type.html#a1350c90c9339b9ad86cde9247163a599',1,'gko::stop::ImplicitResidualNorm::parameters_type::reduction_factor'],['../structgko_1_1stop_1_1ResidualNormReduction_1_1parameters__type.html#a488ffd39d7ea7fc9093a0e7604be2746',1,'gko::stop::ResidualNormReduction::parameters_type::reduction_factor']]],
   ['reference_5fversion_1',['reference_version',['../classgko_1_1version__info.html#a772fcf25f93d719b733602b4bba7d7ec',1,'gko::version_info']]],
-  ['relaxation_5ffactor_2',['relaxation_factor',['../structgko_1_1solver_1_1Ir_1_1parameters__type.html#adde5da5ddad690e275111ea316757707',1,'gko::solver::Ir::parameters_type']]],
+  ['relaxation_5ffactor_2',['relaxation_factor',['../structgko_1_1solver_1_1parameters__type.html#a8d0105656174e1f1934ccecc5839bd5a',1,'gko::solver::parameters_type']]],
   ['reordering_3',['reordering',['../structgko_1_1experimental_1_1reorder_1_1ScaledReordered_1_1parameters__type.html#a3d6bee65ddbd57b2ba3e47ae100828bf',1,'gko::experimental::reorder::ScaledReordered::parameters_type']]],
   ['row_5fscaling_4',['row_scaling',['../structgko_1_1experimental_1_1reorder_1_1ScaledReordered_1_1parameters__type.html#a750986fc3820b0d0ced1de4732277971',1,'gko::experimental::reorder::ScaledReordered::parameters_type']]]
 ];
